The command line interface is the easiest way to build an AEA.

## Installation

The following installs the AEA cli package.

``` bash
pip install aea[cli]
```

The following installs the entire AEA package including the cli.

``` bash
pip install aea[all]

```

## Troubleshooting

To ensure no cache is used run.

``` bash
pip install aea[all] --force --no-cache-dir
```
<br />
